import * as React from 'react';
import { Omit } from '../../helpers/typeUtils';
export declare enum TabsVariant {
    div = "div",
    nav = "nav"
}
export interface TabsProps extends Omit<React.HTMLProps<HTMLElement | HTMLDivElement>, 'onSelect'> {
    /** content rendered inside the Tabs Component. */
    children: React.ReactNode;
    /** additional classes added to the Tabs */
    className?: string;
    /** the index of the active tab */
    activeKey?: number;
    /** handle tab selection */
    onSelect?: (event: React.MouseEvent<HTMLElement, MouseEvent>, eventKey: number) => void;
    /** uniquely identifies the Tabs */
    id?: string;
    /** enables the filled tab list layout */
    isFilled?: boolean;
    /** enables Secondary Tab styling */
    isSecondary?: boolean;
    /** aria-label for the left Scroll Button */
    leftScrollAriaLabel?: string;
    /** aria-label for the right Scroll Button */
    rightScrollAriaLabel?: string;
    /** determines what tag is used around the Tabs. Use "nav" to define the Tabs inside a navigation region */
    variant?: 'div' | 'nav';
    /** provides an accessible label for the Tabs. Labels should be unique for each set of Tabs that are present on a page. When variant is set to nav, this prop should be defined to differentiate the Tabs from other navigation regions on the page. */
    'aria-label'?: string;
}
export interface TabsState {
    showLeftScrollButton: boolean;
    showRightScrollButton: boolean;
    highlightLeftScrollButton: boolean;
    highlightRightScrollButton: boolean;
}
export declare class Tabs extends React.Component<TabsProps, TabsState> {
    tabList: React.RefObject<HTMLUListElement>;
    constructor(props: TabsProps);
    static defaultProps: {
        className: string;
        activeKey: number;
        onSelect: () => any;
        isFilled: boolean;
        isSecondary: boolean;
        leftScrollAriaLabel: string;
        rightScrollAriaLabel: string;
        variant: TabsVariant;
    };
    handleTabClick(event: React.MouseEvent<HTMLElement, MouseEvent>, eventKey: number, tabContentRef: React.RefObject<any>): void;
    handleScrollButtons: () => void;
    scrollLeft: () => void;
    scrollRight: () => void;
    componentDidMount(): void;
    componentWillUnmount(): void;
    render(): JSX.Element;
}
